%% Census_analyzer Analyse the census database
%
%    The scripts loads data on censuses and polities and returns several
%    variables with results, as follows:
%       CP        A matrix with all polities (rows) and years (columns)
%                 indicating the population count from the most recent 
%                 census in a given polity and year.
%       CP10      As CP, but only including censuses no older than 10 years
%                 ('10-year rule')
%       CPW       Total enumerated world population in a given year,
%                 without (first column) and with the 10-year rule (second)
%       CPK       Total enumerated population per continent
%       CPK10     As CPK, but with the 10-year rule
%       SC        Number of independent states (from 1815 onwards):
%                 total(first column), with any census (second) and with
%                 censuses no older than 10 years (third).
%       WI        Number of censuses by census round (rows) and type
%                 (columns)
%       WM        Number of censuses by census round (rows) and month
%                 (columns)
%
%% copyright
% (c) 2019 by Dominik Paprotny, GFZ German Research Centre for Geosciences.
% Use it at your own risk!

%% loading data from xls file
% clear; clc;
% [~, ~, Census] = xlsread('Census_populations.xls','PED','A2:P3914');
% Census(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),Census)) = {''};
% save Census_data

%%
clear; clc;
load Census_data
load Countries_1800_2019.mat Countries

Ter = Countries;
Ter1 = unique(cell2mat(Countries(:,[1 2])),'rows');
TD = cell2mat(Countries(:,[1 6:8]));
Cc = cell2mat(Census(:,[1 5 13 14 15 6]));
CP = zeros(size(Ter1,1),217);
CP(:,1) = Ter1(:,1);

for a=1700:2018
    if a<1800
        ia = logical(ones(size(Ter,1),1));
    else
        ia = logical(zeros(size(Ter,1),1));
        for i=1:size(Ter,1)
            if Ter{i,6}<=a&&Ter{i,7}>a&&ismember(Ter{i,8},1:8)
                ia(i,1)=1;
            else
            end
        end
    end
    St = cell2mat(Ter(ia,1));
    ib = ismember(Ter1(:,1),St);
    for i=1:size(Ter1(:,1),1)
        if ib(i)==1
            ic = Cc(:,1)==Ter1(i,1)&Cc(:,3)<=a&Cc(:,4)>=a;
            if sum(ic)==0
            else
                C2 = Census(ic,:);
                if isempty(C2{end,8})
                    CP(i,a-1698) = CP(i,a-1699);
                else
                    CP(i,a-1698) = C2{end,8};
                end
            end
        else
            CP(i,a-1698) = 0;
        end
    end
end
% 10-year rule
CP10 = CP;
for j=1:size(CP10,1)
    for m=11:size(CP10,2)
        if ismember(CP10(j,m),unique(CP10(j,2:m-11)))
            CP10(j,m)=0;
        else
        end
    end
end
CPW = [sum(CP,1)' sum(CP10,1)'];
% continents
Ter1(309,2) = 2;
Ter1(317,2) = 4;
Ter1([9 12 56 81 83 166 175 178],2) = 5;
CPK = zeros(6,size(CP,2)-1);
for z=1:6
    CPK(z,:) = sum(CP(Ter1(:,2)==z,2:end),1);
end
CPK = CPK';
CPK10 = zeros(6,size(CP10,2)-1);
for z=1:6
    CPK10(z,:) = sum(CP10(Ter1(:,2)==z,2:end),1);
end
CPK10 = CPK10';

% indepedent states
SC=zeros(203,3);
for b=1815:2017
    id = ismember(TD(:,4),[1 3]);
    TD2 = TD(id,:);
    id2 = TD2(:,2)<=b;
    TD3 = TD2(id2,:);
    id3 = TD3(:,3)>b;
    TD4 = TD3(id3,:);
    SC(b-1814,1)=size(TD4,1);
    for c=1:size(TD4,1)
        ie = CP(:,1)==TD4(c,1);
        if CP(ie,b-1698)>0
            SC(b-1814,2)=SC(b-1814,2)+1;
        else
        end
        if CP10(ie,b-1698)>0
            SC(b-1814,3)=SC(b-1814,3)+1;
        else
        end        
    end
end

% census stats
iw = Cc(:,5)==1;
Cc2 = Cc(iw,:);
Census2 = Census(iw,:);
for i=1:33
    ii = i*10+1685;
    iii = i*10+1694;
    in = Cc2(:,2)>=ii&Cc2(:,2)<=iii;
    Census3 = Census2(in,:);
    WI(i,1)=sum(in);
    ik = strcmp(Census3(:,10),'DJ');
    WI(i,2)=sum(ik);
    ik = strcmp(Census3(:,10),'DF');
    WI(i,3)=sum(ik);
    ik = strcmp(Census3(:,10),'RDJ');
    WI(i,4)=sum(ik);    
    ik = strcmp(Census3(:,10),'RDF');
    WI(i,5)=sum(ik);
    for j=1:13
        im = Cc2(in,6)==j-1;
        WM(i,j)=sum(im);
    end
end